//////////////////////////////////////////////////
//
//                      ppa-r
//  point process analysis system: pair correlation
//
//
//      Copyright  November 2004 by TAKENAKA, A.

#include <iostream>
#include <iomanip>

#include "plotarea.h"

void showUsage(void);  //  prototype declaration.

/////////////////////////////////////////////////
//
//

int main (int argc, char** argv)
{
    double r_unit, r_upto;
    const char* file1;
    const char* file2 = NULL;
    bool rvl;

    if (argc < 3 || 5 < argc) {
        showUsage();
        return -1;
    }

    r_unit = atof(argv[1]);
    r_upto = atof(argv[2]);
    file1 = argv[3];  //  if argc = 3, argv[3] is NULL.
    if (argc > 3) {
        file2 = argv[4];  //  if argc = 4, argv[4] is NULL.
    }

    PlotArea plot;

    rvl = plot.loadPoints(file1, file2);
    if (!rvl) {
        return -1;  //  failed to load points.
    }

    rvl = plot.calc_cor(r_unit, r_upto);
    if (!rvl) {
        return -1;  //  failed to calculate r.
    }

    const r_X_Array& results = plot.getResults();

    std::cout << "r\tcor" << std::endl;
    
    //  The next line is to overcome the different interpretation
    //  of setprecision() among compilers.
    // cf http://home.earthlink.net/~ddruml/setpre.html

    std::cout.setf(std::ios::fixed);

    int oldPrec = std::cout.precision();

    for (int i = 0; i < (int) results.size(); ++i) {
        std::cout << std::setprecision(2)
                  << double (results[i].first)
                  << "\t"
                   << std::setprecision(3)
                  << double (results[i].second)
                  << std::endl;
    }

    std::cout.precision(oldPrec);

    return 0;
}

//////////////////////////////////////

void showUsage(void)
{
    std::cout << "ppa-r ver 0.1  2004 by TAKENAKA A." << std::endl;
    std::cout << "USAGE: ppa-r r_unit r_upto file1 [file2]" << std::endl;
    std::cout << "  r_unit is the increment of distance, r." << std::endl;
    std::cout << "  r_upto is the max r." << std::endl;
    std::cout << "  If file2 is not given, pair cor. within a set of points ";
    std::cout << "is caluculated." << std::endl;
    std::cout << "  If file2 is given, pair cor. between two sets of points ";
    std::cout << "is caluculated." << std::endl;
    std::cout << "For details, visit http://takenaka-akio.cool.ne.jp/etc/ppa-r/" << std::endl;
    
}
